@@ -45,6 +45,8 @@ Class structure:
 
     SHGeoid
 
+    SHGradient
+
 For more information, see the documentation for the top level classes.
 """
 from .shcoeffs import SHCoeffs
@@ -78,6 +80,20 @@ from .shmagcoeffs import SHMagRealCoeffs
 from .shmaggrid import SHMagGrid
 from .shtensor import SHMagTensor
 
+from .shgradient import SHGradient
+
+del shcoeffs  # noqa: F821
+del shgrid  # noqa: F821
+del shwindow  # noqa: F821
+del slepian  # noqa: F821
+del slepiancoeffs  # noqa: F821
+del shgravcoeffs  # noqa: F821
+del shgravgrid  # noqa: F821
+del shtensor  # noqa: F821
+del shgeoid  # noqa: F821
+del shmagcoeffs  # noqa: F821
+del shmaggrid  # noqa: F821
+del shgradient  # noqa: F821
 
 # ---- Define __all__ for use with: from pyshtools import * ----
 __all__ = ['SHCoeffs', 'SHRealCoeffs', 'SHComplexCoeffs', 'SHGrid',
@@ -85,4 +101,4 @@ __all__ = ['SHCoeffs', 'SHRealCoeffs', 'SHComplexCoeffs', 'SHGrid',
            'SHWindow', 'SHWindowCap', 'SHWindowMask', 'Slepian', 'SlepianCap',
            'SlepianMask', 'SlepianCoeffs', 'SHGravCoeffs', 'SHGravRealCoeffs',
            'SHGravGrid', 'SHGravTensor', 'SHGeoid', 'SHMagCoeffs',
-           'SHMagRealCoeffs', 'SHMagGrid', 'SHMagTensor']
+           'SHMagRealCoeffs', 'SHMagGrid', 'SHMagTensor', 'SHGradient']
