@@ -12,8 +12,8 @@ import copy as _copy
 from .. import shtools as _shtools
 from ..spectralanalysis import spectrum as _spectrum
 
-from .shcoeffsgrid import SHCoeffs
-from .shcoeffsgrid import SHGrid
+from .shcoeffs import SHCoeffs
+from .shgrid import SHGrid
 
 
 __all__ = ['SHWindow', 'SHWindowCap', 'SHWindowMask']
@@ -474,8 +474,9 @@ class SHWindow(object):
             1-D numpy array of the weights used in calculating the multitaper
             spectral estimates and standard error.
         clat, clon : float, optional, default = 90., 0.
-            Latitude and longitude of the center of the spherical-cap
-            localization windows.
+            When using spherical-cap localization windows, rotate the center of
+            the localization windows to the latitude and longitude coordinates
+            clat and clon, respectively.
         coord_degrees : bool, optional, default = True
             True if clat and clon are in degrees.
         """
@@ -542,8 +543,9 @@ class SHWindow(object):
             The weights used in calculating the multitaper cross-spectral
             estimates and standard error.
         clat, clon : float, optional, default = 90., 0.
-            Latitude and longitude of the center of the spherical-cap
-            localization windows.
+            When using spherical-cap localization windows, rotate the center of
+            the localization windows to the latitude and longitude coordinates
+            clat and clon, respectively.
         coord_degrees : bool, optional, default = True
             True if clat and clon are in degrees.
         """
@@ -1049,10 +1051,22 @@ class SHWindow(object):
         """
         if axes_labelsize is None:
             axes_labelsize = _mpl.rcParams['axes.labelsize']
+            if type(axes_labelsize) == str:
+                axes_labelsize = _mpl.font_manager \
+                                 .FontProperties(size=axes_labelsize) \
+                                 .get_size_in_points()
         if tick_labelsize is None:
             tick_labelsize = _mpl.rcParams['xtick.labelsize']
+            if type(tick_labelsize) == str:
+                tick_labelsize = _mpl.font_manager \
+                                 .FontProperties(size=tick_labelsize) \
+                                 .get_size_in_points()
         if titlesize is None:
             titlesize = _mpl.rcParams['axes.titlesize']
+            if type(titlesize) == str:
+                titlesize = _mpl.font_manager \
+                                 .FontProperties(size=titlesize) \
+                                 .get_size_in_points()
 
         degrees = self.degrees()
         spectrum = self.spectra(nwin=nwin, convention=convention, unit=unit,
@@ -1112,10 +1126,10 @@ class SHWindow(object):
                 axtemp.set_ylabel('Energy', fontsize=axes_labelsize)
 
             if yscale == 'log':
-                axtemp.set_yscale('log', basey=base)
+                axtemp.set_yscale('log', base=base)
 
             if xscale == 'log':
-                axtemp.set_xscale('log', basex=base)
+                axtemp.set_xscale('log', base=base)
                 axtemp.plot(degrees[1:], spectrum[1:, itaper],
                             label='#{:d} [loss={:2.2g}]'
                             .format(itaper, 1-evalue))
@@ -1150,7 +1164,7 @@ class SHWindow(object):
                              vmin=None, vmax=None, xlabel='Input degree',
                              ylabel='Output degree', title=None,
                              axes_labelsize=None, tick_labelsize=None,
-                             title_labelsize=None, colorbar=None,
+                             titlesize=None, colorbar=None,
                              cb_label=None, normalize=False, show=True,
                              ax=None, fname=None, **kwargs):
         """
@@ -1163,7 +1177,7 @@ class SHWindow(object):
         -----
         x.plot_coupling_matrix(lmax, [k, weights, mode, vmin, vmax, xlabel,
                                       ylabel, title, axes_labelsize,
-                                      tick_labelsize, title_labelsize,
+                                      tick_labelsize, titlesize,
                                       colorbar, cb_label, normalize, show, ax,
                                       fname, weights, **kwargs])
 
@@ -1200,7 +1214,7 @@ class SHWindow(object):
             The font size for the x and y axes labels.
         tick_labelsize : int, optional, default = None
             The font size for the x and y tick labels.
-        title_labelsize : int, optional, default = None
+        titlesize : int, optional, default = None
             The font size for the title.
         colorbar : str, optional, default = None
             Plot a colorbar that is either 'horizontal' or 'vertical'.
@@ -1235,10 +1249,22 @@ class SHWindow(object):
 
         if axes_labelsize is None:
             axes_labelsize = _mpl.rcParams['axes.labelsize']
+            if type(axes_labelsize) == str:
+                axes_labelsize = _mpl.font_manager \
+                                 .FontProperties(size=axes_labelsize) \
+                                 .get_size_in_points()
         if tick_labelsize is None:
             tick_labelsize = _mpl.rcParams['xtick.labelsize']
-        if title_labelsize is None:
-            tick_labelsize = _mpl.rcParams['axes.titlesize']
+            if type(tick_labelsize) == str:
+                tick_labelsize = _mpl.font_manager \
+                                 .FontProperties(size=tick_labelsize) \
+                                 .get_size_in_points()
+        if titlesize is None:
+            titlesize = _mpl.rcParams['axes.titlesize']
+            if type(titlesize) == str:
+                titlesize = _mpl.font_manager \
+                                 .FontProperties(size=titlesize) \
+                                 .get_size_in_points()
 
         if ax is None:
             if colorbar is not None:
@@ -1269,7 +1295,7 @@ class SHWindow(object):
         if ylabel is not None:
             axes.set_ylabel(ylabel, fontsize=axes_labelsize)
         if title is not None:
-            axes.set_title(title, fontsize=title_labelsize)
+            axes.set_title(title, fontsize=titlesize)
         axes.tick_params(labelsize=tick_labelsize)
         axes.minorticks_on()
 
@@ -1794,8 +1820,8 @@ class SHWindowMask(SHWindow):
 
         sh = clm.to_array(normalization='4pi', csphase=1, lmax=lmax)
 
-        mtse, sd = _shtools.SHMultiTaperMaskSE(sh, self.tapers, lmax=lmax,
-                                               k=k, taper_wt=weights)
+        mtse, sd = _shtools.SHMultiTaperMaskSE(sh, self.tapers, k=k,
+                                               taper_wt=weights)
 
         if (unit == 'per_l'):
             pass
@@ -1834,8 +1860,7 @@ class SHWindowMask(SHWindow):
         sh2 = slm.to_array(normalization='4pi', csphase=1, lmax=lmax)
 
         mtse, sd = _shtools.SHMultiTaperMaskCSE(sh1, sh2, self.tapers,
-                                                lmax=lmax, k=k,
-                                                taper_wt=weights)
+                                                k=k, taper_wt=weights)
 
         if (unit == 'per_l'):
             pass
